@@ -728,6 +728,20 @@ namespace xsimd
             {
                 return _mm_unpackhi_ps(lhs, rhs);
             }
+
+            static batch_type extract_pair(const batch_type& lhs, const batch_type& rhs, const int n)
+            {
+                batch_type b_concatenate;
+                for (int i = 0 ; i < (4 - n); ++i)
+                {
+                    b_concatenate[i] = lhs[i + n];
+                    if(i < n)
+                    {
+                        b_concatenate[4 - 1 - i] = rhs[n - 1 - i];
+                    }
+                }
+                return b_concatenate;
+            }
         };
     }
 }
